/*
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */



#include "Dialogs/CopyrightWindow.h"
#include "Midi/Sequence.h"

#include <iostream>

#include "wx/wx.h"

#include "Config.h"

namespace AriaMaestosa {
	
class CopyrightWindowClass : public wxDialog
{
    
	DECLARE_LEAK_CHECK();
	
    wxBoxSizer* boxSizer;
    wxTextCtrl* textInput;
    wxButton* okBtn;
    
    Sequence* sequence;
    
    int code;
    
public:
    CopyrightWindowClass(Sequence* seq) : wxDialog( NULL, wxID_ANY, wxGetTranslation("Copyright"), wxDefaultPosition, wxSize(400,400), wxCAPTION )
	{
            
			INIT_LEAK_CHECK();
			
            sequence = seq;
            
            boxSizer=new wxBoxSizer(wxVERTICAL);
            
            // text area
            textInput = new wxTextCtrl( this, wxID_ANY, wxString( sequence->getCopyright().c_str() ), wxDefaultPosition, wxSize(400,75), wxTE_MULTILINE );
            boxSizer->Add( textInput, 0, wxALL, 10 );
            
            // ok button
            okBtn = new wxButton( this, 1, wxT("OK"));
            okBtn->SetDefault();
            boxSizer->Add( okBtn, 0, wxALL, 10 );
            
            SetSizer( boxSizer );
            boxSizer->Layout();
            boxSizer->SetSizeHints( this );
            
        }
    

    void okClicked(wxCommandEvent& evt){
        sequence->setCopyright( (char*)textInput->GetValue().c_str() );
        
        CopyrightWindow::hide();
    }
    
    void show(){
        wxDialog::Center();
        code = wxDialog::ShowModal();
        //wxDialog::Show();
        
        wxYield();
    }
    void hide(){
        wxDialog::EndModal(code);   
        //wxDialog::Hide();
    }
    
    DECLARE_EVENT_TABLE();
    
};

BEGIN_EVENT_TABLE( CopyrightWindowClass, wxDialog )

EVT_BUTTON( 1, CopyrightWindowClass::okClicked )

END_EVENT_TABLE()


namespace CopyrightWindow {
    
    CopyrightWindowClass* copyrightWindow=NULL;
    
    void show(Sequence* seq){

        copyrightWindow = new CopyrightWindowClass(seq);
        copyrightWindow->show();
    }

    void hide(){
        copyrightWindow->hide();
		copyrightWindow->Destroy();
    }
	
	void free()
	{
	}

}

}

